l10n Package
============

:mod:`l10n` Module
------------------

.. automodule:: stoqlib.l10n.l10n
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    stoqlib.l10n.br
    stoqlib.l10n.generic
    stoqlib.l10n.sv

